@@ -1,12 +1,13 @@
 use crate::config::Config;
 use exomind_protos::base::{Account, AccountScope, AccountType};
 use google_gmail1::api::{ModifyMessageRequest, ModifyThreadRequest};
+use google_gmail1::oauth2::{self, InstalledFlowAuthenticator, InstalledFlowReturnMethod};
+use hyper_rustls::HttpsConnectorBuilder;
 use std::{
     collections::HashSet,
     path::PathBuf,
     time::{Duration, Instant},
 };
-use yup_oauth2::{InstalledFlowAuthenticator, InstalledFlowReturnMethod};
 
 const CLIENT_REFRESH_INTERVAL: Duration = Duration::from_secs(5 * 60);
 const FULL_ACCESS_SCOPE: &str = "https://mail.google.com/";
@@ -39,7 +40,7 @@ impl GmailClient {
         info!("Creating gmail client for account {}", account.email());
 
         let token_file = account_token_file(config, account.email())?;
-        let app_secret = yup_oauth2::read_application_secret(&config.client_secret).await?;
+        let app_secret = oauth2::read_application_secret(&config.client_secret).await?;
         let auth =
             InstalledFlowAuthenticator::builder(app_secret, InstalledFlowReturnMethod::Interactive)
                 .persist_tokens_to_disk(token_file)
@@ -48,10 +49,12 @@ impl GmailClient {
 
         auth.token(&[FULL_ACCESS_SCOPE]).await?;
 
-        let client = google_gmail1::Gmail::new(
-            hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()),
-            auth,
-        );
+        let connector = HttpsConnectorBuilder::new()
+            .with_native_roots()
+            .https_only()
+            .enable_http2()
+            .build();
+        let client = google_gmail1::Gmail::new(hyper::Client::builder().build(connector), auth);
 
         Ok(client)
     }
